@@ -17,12 +17,15 @@ FormAbout::FormAbout(QWidget *parent) :
 
     ui->label_2->setText(tr("Version:")+" "+QString(ULCC_VERSION));
     ui->label_3->setText(tr("Date build:")+" "+QString(ULCC_DATEBUILD));
-    ui->label_4->setText("© 2018-2025 DanSoft. "+tr("All rights reserved."));
+    ui->label_4->setText("© 2018-2026 DanSoft. "+tr("All rights reserved."));
     ui->label_5->setPixmap(QPixmap(QString(GLOBAL_PATH_USERDATA)+"/images/icons/ulcc.png"));
 
     connect(ui->pushButton,SIGNAL(clicked(bool)),this,SLOT(close()));
     connect(ui->pushButton_2,SIGNAL(clicked(bool)),this,SLOT(visit_web_site()));
     connect(ui->pushButton_3,SIGNAL(clicked(bool)),this,SLOT(visit_bitbucket()));
+
+    //
+    ui->pushButton_2->setVisible(false);
 }
 
 FormAbout::~FormAbout()
